@@ -16,8 +16,8 @@ def api_get(table,kwargs:dict):
         if val is not None and key!="_api_key":
             if type(val)==str:
                 query_val = val
-            elif type(val) == UUID:
-                query_val = val.bytes
+            # elif type(val) == UUID:
+            #     query_val = val.bytes
             else:
                 query_val = str(val)
             k[key]=query_val
